;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "autothemer" "20260530.2349"
  "Conveniently define themes."
  '((dash  "2.10.0")
    (emacs "26.1"))
  :url "https://github.com/jasonm23/autothemer"
  :commit "99fd9b45ef6cc931fcf030b1a6c050ca3c17ce04"
  :revdesc "99fd9b45ef6c"
  :maintainers '(("Jason Milkins" . "jasonm23@gmail.com")))
